@@ -11,6 +11,10 @@ use Function::Parameters;
 use GraphQL::Parser;
 use GraphQL::Error;
 use JSON::MaybeXS;
+use GraphQL::Debug qw(_debug);
+use GraphQL::Introspection qw(
+  $SCHEMA_META_FIELD_DEF $TYPE_META_FIELD_DEF $TYPE_NAME_META_FIELD_DEF
+);
 
 =head1 NAME
 
@@ -21,6 +25,7 @@ GraphQL::Execution - Execute GraphQL queries
 our $VERSION = '0.02';
 
 my $JSON = JSON::MaybeXS->new->allow_nonref;
+use constant DEBUG => $ENV{GRAPHQL_DEBUG}; # "DEBUG and" gets optimised out if false
 
 =head1 SYNOPSIS
 
@@ -120,25 +125,32 @@ fun _build_context(
   };
 }
 
+# takes each operation var: query q(a: String)
+#  applies to it supplied variable from web request
+#  if none, applies any defaults in the operation var: query q(a: String = "h")
+#  converts with graphql_to_perl (which also validates) to Perl values
+# return { varname => { value => ..., type => $type } }
 fun _variables_apply_defaults(
   (InstanceOf['GraphQL::Schema']) $schema,
   HashRef $operation_variables,
   HashRef $variable_values,
 ) :ReturnType(HashRef) {
-  my %new_values;
-  map {
+  my @bad = grep {
+    ! _lookup_type($schema, $operation_variables->{$_})->DOES('GraphQL::Role::Input');
+  } keys %$operation_variables;
+  die "Variable '\$$bad[0]' is type '@{[
+    _lookup_type($schema, $operation_variables->{$bad[0]})->to_string
+  ]}' which cannot be used as an input type.\n" if @bad;
+  +{ map {
     my $opvar = $operation_variables->{$_};
     my $opvar_type = _lookup_type($schema, $opvar);
-    die "Variable '\$$_' is type '@{[$opvar_type->to_string]}' which cannot be used as an input type.\n"
-      if !$opvar_type->DOES('GraphQL::Role::Input');
     my $parsed_value;
     my $maybe_value = $variable_values->{$_} // $opvar->{default_value};
     eval { $parsed_value = $opvar_type->graphql_to_perl($maybe_value) };
     die "Variable '\$$_' got invalid value @{[$JSON->canonical->encode($maybe_value)]}.\n$@"
       if $@;
-    $new_values{$_} = $parsed_value;
-  } keys %$operation_variables;
-  \%new_values;
+    ($_ => { value => $parsed_value, type => $opvar_type })
+  } keys %$operation_variables };
 }
 
 fun _lookup_type(
@@ -153,13 +165,13 @@ fun _lookup_type(
 
 sub _get_operation {
   my ($operation_name, $operations) = @_;
-  my $operation;
+  DEBUG and _debug('_get_operation', @_);
   if (!$operation_name) {
     die "Must provide operation name if query contains multiple operations."
       if @$operations > 1;
     return $operations->[0];
   }
-  my @matching = grep $_->{name} eq $operation_name, @$operations;
+  my @matching = grep $_->{node}{name} eq $operation_name, @$operations;
   return $matching[0] if @matching == 1;
   die "No operations matching '$operation_name' found.";
 }
@@ -198,6 +210,7 @@ fun _collect_fields(
   Map[StrNameValid,ArrayRef[HashRef]] $fields_got,
   Map[StrNameValid,Bool] $visited_fragments,
 ) :ReturnType(Map[StrNameValid,ArrayRef[HashRef]]) {
+  DEBUG and _debug('_collect_fields', $runtime_type->to_string, $fields_got, $selections);
   for my $selection (@$selections) {
     my $node = $selection->{node};
     next if !_should_include_node($context, $node);
@@ -207,6 +220,7 @@ fun _collect_fields(
       push @{ $fields_got->{$use_name} }, $node;
     } elsif ($selection->{kind} eq 'inline_fragment') {
       next if !_fragment_condition_match($context, $node, $runtime_type);
+      next if !_should_include_node($context, $node);
       _collect_fields(
         $context,
         $runtime_type,
@@ -217,14 +231,16 @@ fun _collect_fields(
     } elsif ($selection->{kind} eq 'fragment_spread') {
       my $frag_name = $node->{name};
       next if $visited_fragments->{$frag_name};
+      next if !_should_include_node($context, $node);
       $visited_fragments->{$frag_name} = 1;
       my $fragment = $context->{fragments}{$frag_name};
       next if !$fragment;
       next if !_fragment_condition_match($context, $fragment, $runtime_type);
+      DEBUG and _debug('_collect_fields(fragment_spread)', $fragment);
       _collect_fields(
         $context,
         $runtime_type,
-        $node->{selections},
+        $fragment->{selections},
         $fields_got,
         $visited_fragments,
       );
@@ -246,8 +262,15 @@ fun _fragment_condition_match(
   HashRef $node,
   (InstanceOf['GraphQL::Type']) $runtime_type,
 ) :ReturnType(Bool) {
-  # TODO implement
-  1;
+  DEBUG and _debug('_fragment_condition_match', $runtime_type->to_string, $node);
+  return 1 if !$node->{on};
+  return 1 if $node->{on} eq $runtime_type->name;
+  my $condition_type = $context->{schema}->name2type->{$node->{on}} //
+    die GraphQL::Error->new(
+      message => "Unknown type for fragment condition '$node->{on}'."
+    );
+  return '' if !$condition_type->DOES('GraphQL::Role::Abstract');
+  $context->{schema}->is_possible_type($condition_type, $runtime_type);
 }
 
 fun _execute_fields(
@@ -258,6 +281,7 @@ fun _execute_fields(
   Map[StrNameValid,ArrayRef[HashRef]] $fields,
 ) :ReturnType(Map[StrNameValid,Any]){
   my %results;
+  DEBUG and _debug('_execute_fields', $parent_type->to_string, $fields, $root_value);
   map {
     my $result_name = $_;
     my $result = _resolve_field(
@@ -280,6 +304,9 @@ fun _execute_fields_serially(
   ArrayRef $path,
   Map[StrNameValid,ArrayRef[HashRef]] $fields,
 ) {
+  DEBUG and _debug('_execute_fields_serially', $parent_type->to_string, $fields, $root_value);
+  # TODO implement
+  goto &_execute_fields;
 }
 
 # NB same ordering as _execute_fields - graphql-js switches last 2
@@ -292,6 +319,7 @@ fun _resolve_field(
 ) {
   my $field_node = $nodes->[0];
   my $field_name = $field_node->{name};
+  DEBUG and _debug('_resolve_field', $parent_type->to_string, $nodes, $root_value);
   my $field_def = _get_field_def($context->{schema}, $parent_type, $field_name);
   return if !$field_def;
   my $resolve = $field_def->{resolve} || $context->{field_resolver};
@@ -320,13 +348,22 @@ fun _resolve_field(
   );
 }
 
+use constant FIELDNAME2SPECIAL => {
+  map { ($_->{name} => $_) } $SCHEMA_META_FIELD_DEF, $TYPE_META_FIELD_DEF
+};
 fun _get_field_def(
   (InstanceOf['GraphQL::Schema']) $schema,
   (InstanceOf['GraphQL::Type']) $parent_type,
   StrNameValid $field_name,
 ) :ReturnType(HashRef) {
-  # TODO __schema and __typename and __type
-  $parent_type->fields->{$field_name};
+  return $TYPE_NAME_META_FIELD_DEF
+    if $field_name eq $TYPE_NAME_META_FIELD_DEF->{name};
+  return FIELDNAME2SPECIAL->{$field_name}
+    if FIELDNAME2SPECIAL->{$field_name} and $parent_type == $schema->query;
+  $parent_type->fields->{$field_name} //
+    die GraphQL::Error->new(
+      message => "No field @{[$parent_type->name]}.$field_name."
+    );
 }
 
 # NB similar ordering as _execute_fields - graphql-js switches
@@ -359,6 +396,7 @@ fun _resolve_field_value_or_error(
   Maybe[Any] $root_value,
   HashRef $info,
 ) {
+  DEBUG and _debug('_resolve_field_value_or_error', $nodes, $root_value, $field_def);
   my $result = eval {
     my $args = _get_argument_values($field_def, $nodes->[0], $context->{variable_values});
     $resolve->($root_value, $args, $context->{context_value}, $info);
@@ -417,16 +455,178 @@ fun _complete_value(
   ArrayRef $path,
   Any $result,
 ) {
+  DEBUG and _debug('_complete_value', $return_type->to_string, $result);
   # TODO promise stuff
   die $result if GraphQL::Error->is($result);
-  return $result if !defined $result;
-  # TODO handle list
-  # TODO handle leaf
-  # TODO handle abstract
-  # TODO handle object
   if ($return_type->isa('GraphQL::Type::NonNull')) {
+    my $completed = _complete_value(
+      $context,
+      $return_type->of,
+      $nodes,
+      $info,
+      $path,
+      $result,
+    );
+    die GraphQL::Error->new(
+      message => "Cannot return null for non-nullable field @{[$info->{parent_type}->name]}.@{[$info->{field_name}]}."
+    ) if !defined $completed;
+    return $completed;
   }
-  $result;
+  return $result if !defined $result;
+  return _complete_list_value(@_) if $return_type->isa('GraphQL::Type::List');
+  return _complete_leaf_value($return_type, $result)
+    if $return_type->DOES('GraphQL::Role::Leaf');
+  return _complete_abstract_value(@_) if $return_type->DOES('GraphQL::Role::Abstract');
+  return _complete_object_value(@_) if $return_type->isa('GraphQL::Type::Object');
+  # shouldn't get here
+  die GraphQL::Error->new(
+    message => "Cannot complete value of unexpected type '@{[$return_type->to_string]}'."
+  );
+}
+
+fun _complete_list_value(
+  HashRef $context,
+  (InstanceOf['GraphQL::Type::List']) $return_type,
+  ArrayRef[HashRef] $nodes,
+  HashRef $info,
+  ArrayRef $path,
+  ArrayRef $result,
+) {
+  # TODO promise stuff
+  my $item_type = $return_type->of;
+  my $index = 0;
+  my @completed_results = map {
+    _complete_value_catching_error(
+      $context,
+      $item_type,
+      $nodes,
+      $info,
+      [ @$path, $index++ ],
+      $_,
+    );
+  } @$result;
+  \@completed_results;
+}
+
+fun _complete_leaf_value(
+  (ConsumerOf['GraphQL::Role::Leaf']) $return_type,
+  Any $result,
+) {
+  DEBUG and _debug('_complete_leaf_value', $return_type->to_string, $result);
+  my $serialised = $return_type->perl_to_graphql($result);
+  die GraphQL::Error->new(message => "Expected a value of type '@{[$return_type->to_string]}' but received: '$result'.\n$@") if $@;
+  $serialised;
+}
+
+fun _complete_abstract_value(
+  HashRef $context,
+  (ConsumerOf['GraphQL::Role::Abstract']) $return_type,
+  ArrayRef[HashRef] $nodes,
+  HashRef $info,
+  ArrayRef $path,
+  Any $result,
+) {
+  my $runtime_type = ($return_type->resolve_type || \&_default_resolve_type)->(
+    $result, $context->{context_value}, $info, $return_type
+  );
+  # TODO promise stuff
+  _complete_object_value(
+    $context,
+    _ensure_valid_runtime_type(
+      $runtime_type,
+      $context,
+      $return_type,
+      $nodes,
+      $info,
+      $result,
+    ),
+    $nodes,
+    $info,
+    $path,
+    $result,
+  );
+}
+
+fun _ensure_valid_runtime_type(
+  (Str | InstanceOf['GraphQL::Type::Object']) $runtime_type_or_name,
+  HashRef $context,
+  (ConsumerOf['GraphQL::Role::Abstract']) $return_type,
+  ArrayRef[HashRef] $nodes,
+  HashRef $info,
+  Any $result,
+) :ReturnType(InstanceOf['GraphQL::Type::Object']) {
+  my $runtime_type = is_InstanceOf($runtime_type_or_name)
+    ? $runtime_type_or_name
+    : $context->{schema}->name2type->{$runtime_type_or_name};
+  die GraphQL::Error->new(
+    message => "Abstract type @{[$return_type->name]} must resolve to an " .
+      "Object type at runtime for field @{[$info->{parent_type}->name]}." .
+      "@{[$info->{field_name}]} with value $result, received '@{[$runtime_type->name]}'.",
+    nodes => [ $nodes ],
+  ) if !$runtime_type->isa('GraphQL::Type::Object');
+  die GraphQL::Error->new(
+    message => "Runtime Object type '@{[$runtime_type->name]}' is not a possible type for " .
+      "'@{[$return_type->name]}'.",
+    nodes => [ $nodes ],
+  ) if !$context->{schema}->is_possible_type($return_type, $runtime_type);
+  $runtime_type;
+}
+
+fun _default_resolve_type(
+  Any $value,
+  Any $context,
+  HashRef $info,
+  (ConsumerOf['GraphQL::Role::Abstract']) $abstract_type,
+) {
+  my @possibles = @{ $info->{schema}->get_possible_types($abstract_type) };
+  # TODO promise stuff
+  (grep $_->is_type_of->($value, $context, $info), grep $_->is_type_of, @possibles)[0];
+}
+
+fun _complete_object_value(
+  HashRef $context,
+  (InstanceOf['GraphQL::Type::Object']) $return_type,
+  ArrayRef[HashRef] $nodes,
+  HashRef $info,
+  ArrayRef $path,
+  Any $result,
+) {
+  if ($return_type->is_type_of) {
+    my $is_type_of = $return_type->is_type_of->($result, $context->{context_value}, $info);
+    # TODO promise stuff
+    die GraphQL::Error->new(message => "Expected a value of type '@{[$return_type->to_string]}' but received: '$result'") if !$is_type_of;
+  }
+  _collect_and_execute_subfields(
+    $context,
+    $return_type,
+    $nodes,
+    $info,
+    $path,
+    $result,
+  );
+}
+
+fun _collect_and_execute_subfields(
+  HashRef $context,
+  (InstanceOf['GraphQL::Type::Object']) $return_type,
+  ArrayRef[HashRef] $nodes,
+  HashRef $info,
+  ArrayRef $path,
+  Any $result,
+) {
+  my $subfield_nodes = {};
+  my $visited_fragment_names = {};
+  for (grep $_->{selections}, @$nodes) {
+    $subfield_nodes = _collect_fields(
+      $context,
+      $return_type,
+      $_->{selections},
+      $subfield_nodes,
+      $visited_fragment_names,
+    );
+  }
+  DEBUG and _debug('_collect_and_execute_subfields', $return_type->to_string, $subfield_nodes);
+  _execute_fields($context, $return_type, $result, $path, $subfield_nodes);
 }
 
 fun _located_error(
@@ -445,6 +645,7 @@ fun _get_argument_values(
 ) {
   my $arg_defs = $def->{args};
   my $arg_nodes = $node->{arguments};
+  DEBUG and _debug("_get_argument_values", $arg_defs, $arg_nodes, $variable_values);
   return {} if !$arg_defs;
   my @bad = grep { !exists $arg_nodes->{$_} and !defined $arg_defs->{$_}{default_value} and $arg_defs->{$_}{type}->isa('GraphQL::Type::NonNull') } keys %$arg_defs;
   die GraphQL::Error->new(
@@ -452,6 +653,16 @@ fun _get_argument_values(
       "'@{[$arg_defs->{$bad[0]}{type}->to_string]}' not given.",
     nodes => [ $node ],
   ) if @bad;
+  @bad = grep {
+    ref($arg_nodes->{$_}) eq 'SCALAR' and
+    $variable_values->{${$arg_nodes->{$_}}} and
+    !_type_will_accept($arg_defs->{$_}{type}, $variable_values->{${$arg_nodes->{$_}}}{type})
+  } keys %$arg_defs;
+  die GraphQL::Error->new(
+    message => "Variable '\$${$arg_nodes->{$bad[0]}}' of type '@{[$variable_values->{${$arg_nodes->{$bad[0]}}}{type}->to_string]}'".
+      " where expected '@{[$arg_defs->{$bad[0]}{type}->to_string]}'.",
+    nodes => [ $node ],
+  ) if @bad;
   my @novar = grep {
     ref($arg_nodes->{$_}) eq 'SCALAR' and
     (!$variable_values or !exists $variable_values->{${$arg_nodes->{$_}}}) and
@@ -475,6 +686,16 @@ fun _get_argument_values(
       " was given ${${$arg_nodes->{$enumfail[0]}}} which is enum value.",
     nodes => [ $node ],
   ) if @enumfail;
+  my @enumstring = grep {
+    defined($arg_nodes->{$_}) and
+    !ref($arg_nodes->{$_})
+  } grep $arg_defs->{$_}{type}->isa('GraphQL::Type::Enum'), keys %$arg_defs;
+  die GraphQL::Error->new(
+    message => "Argument '$enumstring[0]' of type ".
+      "'@{[$arg_defs->{$enumstring[0]}{type}->to_string]}'".
+      " was given '$arg_nodes->{$enumstring[0]}' which is not enum value.",
+    nodes => [ $node ],
+  ) if @enumstring;
   return {} if !$arg_nodes;
   my %coerced_values;
   for my $name (keys %$arg_defs) {
@@ -482,14 +703,22 @@ fun _get_argument_values(
     my $arg_type = $arg_def->{type};
     my $argument_node = $arg_nodes->{$name};
     my $default_value = $arg_def->{default_value};
+    DEBUG and _debug("_get_argument_values($name)", $arg_def, $arg_type, $argument_node, $default_value);
     if (!exists $arg_nodes->{$name}) {
+      # none given - apply type arg's default if any. already validated perl
       $coerced_values{$name} = $default_value if exists $arg_def->{default_value};
+      next;
     } elsif (ref($argument_node) eq 'SCALAR') {
-      # scalar ref means it's a variable
+      # scalar ref means it's a variable. already validated perl
       $coerced_values{$name} =
-        ($variable_values && $variable_values->{$$argument_node})
+        ($variable_values && $variable_values->{$$argument_node} && $variable_values->{$$argument_node}{value})
         // $default_value;
+      next;
+    } elsif (ref($argument_node) eq 'REF') {
+      # double ref means it's an enum value. JSON land, needs convert/validate
+      $coerced_values{$name} = $$$argument_node;
     } else {
+      # query literal. JSON land, needs convert/validate
       $coerced_values{$name} = $argument_node;
     }
     next if !exists $coerced_values{$name};
@@ -506,6 +735,17 @@ fun _get_argument_values(
   \%coerced_values;
 }
 
+fun _type_will_accept(
+  (ConsumerOf['GraphQL::Role::Input']) $arg_type,
+  (ConsumerOf['GraphQL::Role::Input']) $var_type,
+) {
+  return 1 if $arg_type == $var_type;
+  $arg_type = $arg_type->of if $arg_type->isa('GraphQL::Type::NonNull');
+  $var_type = $var_type->of if $var_type->isa('GraphQL::Type::NonNull');
+  return 1 if $arg_type == $var_type;
+  '';
+}
+
 # $root_value is either a hash with fieldnames as keys and either data
 #   or coderefs as values
 # OR it's just a coderef itself
@@ -521,10 +761,13 @@ fun _default_field_resolver(
   my $property = is_HashRef($root_value)
     ? $root_value->{$field_name}
     : $root_value;
+  DEBUG and _debug('_default_field_resolver', $root_value, $field_name, $args, $property);
   if (eval { CodeLike->($property); 1 }) {
+    DEBUG and _debug('_default_field_resolver', 'codelike');
     return $property->($args, $context, $info);
   }
   if (is_InstanceOf($root_value) and $root_value->can($field_name)) {
+    DEBUG and _debug('_default_field_resolver', 'method');
     return $root_value->$field_name($args, $context, $info);
   }
   $property;
