@@ -8,8 +8,12 @@ use Types::Standard -all;
 use GraphQL::Type::Library -all;
 use Return::Type;
 use Function::Parameters;
+use GraphQL::Debug qw(_debug);
+use GraphQL::Directive;
+use GraphQL::Introspection qw($SCHEMA_META_TYPE);
 
 our $VERSION = '0.02';
+use constant DEBUG => $ENV{GRAPHQL_DEBUG};
 
 =head1 NAME
 
@@ -71,7 +75,11 @@ has types => (
 
 =cut
 
-has directives => (is => 'ro', isa => ArrayRef[InstanceOf['GraphQL::Directive']]);
+has directives => (
+  is => 'ro',
+  isa => ArrayRef[InstanceOf['GraphQL::Directive']],
+  default => sub { \@GraphQL::Directive::SPECIFIED_DIRECTIVES },
+);
 
 =head1 METHODS
 
@@ -85,7 +93,7 @@ type object.
 has name2type => (is => 'lazy', isa => Map[StrNameValid, ConsumerOf['GraphQL::Role::Named']]);
 sub _build_name2type {
   my ($self) = @_;
-  my @types = grep $_, map $self->$_, qw(query mutation subscription); # TODO also __Schema
+  my @types = grep $_, (map $self->$_, qw(query mutation subscription)), $SCHEMA_META_TYPE;
   push @types, @{ $self->types || [] };
   my %name2type;
   map _expand_type(\%name2type, $_), @types;
@@ -111,7 +119,7 @@ fun _expand_type(
   my @types;
   push @types, ($type, map @{ _expand_type($map, $_) }, @{ $type->interfaces || [] })
     if $type->isa('GraphQL::Type::Object');
-  push @types, ($type, map @{ _expand_type($map, $_) }, $type->get_types)
+  push @types, ($type, map @{ _expand_type($map, $_) }, @{ $type->get_types })
     if $type->isa('GraphQL::Type::Union');
   if (grep $type->DOES($_), qw(GraphQL::Role::FieldsInput GraphQL::Role::FieldsOutput)) {
     my $fields = $type->fields||{};
@@ -119,6 +127,7 @@ fun _expand_type(
       map @{ _expand_type($map, $_->{type}) }, $_, values %{ $_->{args}||{} }
     } values %$fields;
   }
+  DEBUG and _debug('_expand_type', \@types);
   \@types;
 }
 
