@@ -6,7 +6,7 @@ use warnings;
 use Moo;
 use GraphQL::Type::Library -all;
 use Types::Standard -all;
-use JSON::MaybeXS;
+use JSON::MaybeXS qw(JSON is_bool);
 use Exporter qw(import);
 extends qw(GraphQL::Type);
 with qw(
@@ -18,10 +18,13 @@ with qw(
 );
 use Function::Parameters;
 use Return::Type;
+use GraphQL::Debug qw(_debug);
 
 our $VERSION = '0.02';
 our @EXPORT_OK = qw($Int $Float $String $Boolean $ID);
 
+use constant DEBUG => $ENV{GRAPHQL_DEBUG};
+
 =head1 NAME
 
 GraphQL::Type::Scalar - GraphQL scalar type
@@ -89,6 +92,10 @@ method graphql_to_perl(Any $item) :ReturnType(Any) {
   $self->parse_value->($item);
 }
 
+method perl_to_graphql(Any $item) :ReturnType(Any) {
+  $self->serialize->($item);
+}
+
 =head1 EXPORTED VARIABLES
 
 =head2 $Int
@@ -141,7 +148,7 @@ our $Boolean = GraphQL::Type::Scalar->new(
   description =>
     'The `Boolean` scalar type represents `true` or `false`.',
   serialize => sub { defined $_[0] and Bool->(@_); $_[0] ? JSON->true : JSON->false },
-  parse_value => sub { defined $_[0] and Bool->(@_); $_[0] },
+  parse_value => sub { defined $_[0] and is_bool(@_); $_[0]+0 },
 );
 
 =head2 $ID
